@@ -1,4 +1,5 @@
 import copy
+import html
 import pkg_resources
 import warnings
 
@@ -13,8 +14,9 @@ from pyqtgraph.graphicsItems.GradientEditorItem import Gradients
 
 from .. import plot_cache
 from .. import util
+from .widgets import ShapeOutColorBarItem
 
-from .widgets import ColorBarWidget, SimplePlotItem
+from .widgets import SimplePlotItem
 
 
 # Register custom colormaps
@@ -51,7 +53,7 @@ class PipelinePlot(QtWidgets.QWidget):
         # used to avoid unnecessary plotting
         self._plot_data_hash = "unset"
 
-        #: Contains the PipelinePlotItmes
+        #: Contains the PipelinePlotItems
         self.plot_items = []
         self.pipeline = pipeline
         self.identifier = plot_id
@@ -107,6 +109,9 @@ class PipelinePlot(QtWidgets.QWidget):
         # clear widget
         self.plot_layout.clear()
 
+        # set background to white
+        self.plot_layout.setBackground("w")
+
         if not slot_states:
             return
 
@@ -114,11 +119,14 @@ class PipelinePlot(QtWidgets.QWidget):
 
         # font size for plot title (default size + 2)
         size = "{}pt".format(QtGui.QFont().pointSize() + 2)
-        self.plot_layout.addLabel(lay["name"], colspan=3, size=size)
+        self.plot_layout.addLabel(html.escape(lay["name"]),
+                                  colspan=3,
+                                  size=size)
         self.plot_layout.nextRow()
 
         self.plot_layout.addLabel(labely, angle=-90)
         linner = self.plot_layout.addLayout()
+        linner.setContentsMargins(0, 0, 0, 0)  # reallocate some space
 
         self.plot_items.clear()
 
@@ -179,8 +187,7 @@ class PipelinePlot(QtWidgets.QWidget):
         colorbar_kwds = {}
 
         if sca["marker hue"] == "kde":
-            colorbar_kwds["vmin"] = 0
-            colorbar_kwds["vmax"] = 1
+            colorbar_kwds["values"] = (0, 1)
             colorbar_kwds["label"] = "density [a.u.]"
         elif sca["marker hue"] == "feature":
             feat = sca["hue feature"]
@@ -193,18 +200,19 @@ class PipelinePlot(QtWidgets.QWidget):
                         break
             colorbar_kwds["label"] = label
             if label.endswith("[a.u.]"):
-                colorbar_kwds["vmin"] = 0
-                colorbar_kwds["vmax"] = 1
+                colorbar_kwds["values"] = (0, 1)
             else:
-                colorbar_kwds["vmin"] = sca["hue min"]
-                colorbar_kwds["vmax"] = sca["hue max"]
+                colorbar_kwds["values"] = (sca["hue min"], sca["hue max"])
 
         if colorbar_kwds:
             # add colorbar
-            colorbar = ColorBarWidget(
-                cmap=sca["colormap"],
+            cmap = pg.ColorMap(*zip(*Gradients[sca["colormap"]]["ticks"]))
+            colorbar = ShapeOutColorBarItem(
+                yoffset=31,  # this is heuristic
+                height=min(300, lay["size y"] // 2),
+                cmap=cmap,
+                interactive=False,
                 width=15,
-                height=min(300, lay["size y"]//2),
                 **colorbar_kwds
             )
             self.plot_layout.addItem(colorbar)
@@ -219,6 +227,7 @@ class PipelinePlot(QtWidgets.QWidget):
         size_hint = self.parent().sizeHint()
         parent.setMinimumSize(size_hint)
         parent.setMaximumSize(size_hint)
+        self.plot_layout.updateGeometry()
 
 
 class PipelinePlotItem(SimplePlotItem):
@@ -232,6 +241,8 @@ class PipelinePlotItem(SimplePlotItem):
         self.axes_to_front()
         # Keep track of all elements (for redraw)
         self._plot_elements = []
+        # Set background to white (for plot export)
+        self.vb.setBackgroundColor("w")
 
     def perform_export(self, file):
         """Performs export in new layout with axes labels set
@@ -328,7 +339,7 @@ class PipelinePlotItem(SimplePlotItem):
                 # only one scatter plot
                 ss = slot_states[0]
                 self.setTitle("")  # fake title
-                add_label(text=ss["name"],
+                add_label(text=html.escape(ss["name"]),
                           anchor_parent=self.titleLabel.item,
                           color=ss["color"],
                           text_halign="center",
@@ -341,6 +352,7 @@ class PipelinePlotItem(SimplePlotItem):
                         add_label(text="{} events".format(len(sct[0].data)),
                                   anchor_parent=self.axes["right"]["item"],
                                   font_size_diff=-1,
+                                  color="black",
                                   text_halign="right",
                                   text_valign="top",
                                   dx=2,
@@ -352,6 +364,7 @@ class PipelinePlotItem(SimplePlotItem):
                 # only a contour plot
                 self.setTitle("")  # fake title
                 add_label(text="Contours",
+                          color="black",
                           anchor_parent=self.titleLabel.item,
                           text_halign="center",
                           text_valign="top",
@@ -586,23 +599,31 @@ def add_scatter(plot_item, plot_state, rtdc_ds, slot_state):
 
 def get_axes_labels(plot_state, slot_states):
     gen = plot_state["general"]
-    labelx = dclab.dfn.get_feature_label(gen["axis x"])
-    labely = dclab.dfn.get_feature_label(gen["axis y"])
-    # replace FL-? with user-defined names
-    fl_names = slot_states[0]["fl names"]
-    if labelx.count("FL"):
-        for key in fl_names:
-            if key in labelx:
-                labelx = labelx.replace(key, fl_names[key])
-                break
-    if labely.count("FL"):
-        for key in fl_names:
-            if key in labely:
-                labely = labely.replace(key, fl_names[key])
-                break
+    # Use slot_states[0] because we only have one x-axis label
+    labelx = get_axis_label_from_feature(gen["axis x"], slot_states[0])
+    labely = get_axis_label_from_feature(gen["axis y"], slot_states[0])
     return labelx, labely
 
 
+def get_axis_label_from_feature(feat, slot_state=None):
+    """Return the axis label for plotting given a feature name
+
+    - replace the fluorescence names with user-defined strings
+      from `slot_state["fl names"]` if `slot_state` is given
+    - html-escape all characters
+    """
+    label = dclab.dfn.get_feature_label(feat)
+    # replace FL-? with user-defined names
+    if slot_state is not None and "fl names" in slot_state:
+        fl_names = slot_state["fl names"]
+        if label.count("FL") and feat.startswith("fl"):
+            for key in fl_names:
+                if key in label:
+                    label = label.replace(key, fl_names[key])
+                    break
+    return html.escape(label)
+
+
 def set_viewbox(plot, range_x, range_y, scale_x="linear", scale_y="linear",
                 padding=0):
     # Set Log scale
